LogInterceptorContext class final

Provides contextual information for a LogInterceptor invocation.

This context is passed to each log interceptor and can be used to provide additional data or interfaces that may influence how log events are processed. For example, it may contain a reference to the LoggingInterface that originated the log event.

Typically, you do not need to construct this class directly; it is created and managed by the logging framework.

See also:

Constructors

LogInterceptorContext({LoggingInterface? interface})
Creates a new LogInterceptorContext.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
interface LoggingInterface?
The LoggingInterface associated with this context, if any.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited