LoggingInitialization mixin

Default initialization behavior for interfaces that opt into lifecycle.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
initialized bool
Whether this logging destination has completed initialization.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init() Future<void>
Initializes this logging destination.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited