ArcaneService class abstract
An abstract class representing a service in the Arcane architecture.
Classes that extend ArcaneService can use ChangeNotifier functionality
to notify listeners of changes. Services are typically registered in
ArcaneServiceProvider and can be accessed using the service
method on BuildContext.
- Mixed-in types
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
ofType<
T extends ArcaneService> (BuildContext context) → T? - Retrieves a service of the specified type from the context.
-
requiredOfType<
T extends ArcaneService> (BuildContext context) → T - Retrieves a service of the specified type from the context.